@@ -1,7 +1,7 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
  
-  $Id: libmecab.cpp,v 1.20 2004/06/21 09:34:35 taku-ku Exp $;
+  $Id: libmecab.cpp,v 1.21 2004/08/06 18:05:14 taku-ku Exp $;
 
   Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
   This is free software with ABSOLUTELY NO WARRANTY.
@@ -31,7 +31,7 @@ static std::string errorStr;
 
 struct _mecab_t {
    int allocated;
-   void *ptr;
+   MeCab::Tagger* ptr;
 };
 
 #ifdef _WIN32
@@ -62,10 +62,11 @@ mecab_t* mecab_new (int argc, char **argv)
      errorStr = std::string ("mecab_new(): ");
      errorStr += ptr->what ();      
      delete ptr;
+     delete c;       
      return 0;
    }
 
-   c->ptr = static_cast<void *>(ptr);
+   c->ptr = ptr;
    c->allocated = 1;
    return c;
 }
@@ -83,10 +84,11 @@ mecab_t* mecab_new2 (char *arg)
      errorStr = std::string ("mecab_new2(): ");
      errorStr += ptr->what ();      
      delete ptr;
+     delete c; 
      return 0;
    }
 
-   c->ptr = static_cast<void *>(ptr);
+   c->ptr = ptr;
    c->allocated = 1;
    return c;
 }
@@ -94,15 +96,13 @@ mecab_t* mecab_new2 (char *arg)
 char* mecab_strerror (mecab_t *c)
 {
    if (! c || ! c->allocated) return const_cast<char *>(errorStr.c_str ());
-   MeCab::Tagger *t = static_cast<MeCab::Tagger *>(c->ptr);   
-   return const_cast<char *>(t->what());
+   return const_cast<char *>(c->ptr->what());
 }
 
 void mecab_destroy (mecab_t *c)
 {
   if (c && c->allocated) {
-     MeCab::Tagger *t = static_cast<MeCab::Tagger *>(c->ptr);
-     delete t;
+     delete c->ptr;
      delete c;
   }
   c = 0;
@@ -114,7 +114,7 @@ void mecab_destroy (mecab_t *c)
     errorStr += ": first argment seems to be invalid"; \
     return 0; \
  } \
- MeCab::Tagger *(t) = static_cast<MeCab::Tagger *>((c)->ptr);
+ MeCab::Tagger *(t) = (c)->ptr;
 
 int mecab_lock (mecab_t *c)
 {
