@@ -1,26 +1,25 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+ 
+  $Id: mecab.h,v 1.29 2004/06/21 09:34:35 taku-ku Exp $;
 
-  $Id: mecab.h,v 1.27 2003/07/02 14:31:00 taku-ku Exp $;
-
-  Copyright (C) 2001-2002  Taku Kudo <taku-ku@is.aist-nara.ac.jp>
-  All rights reserved.
-
+  Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
+  This is free software with ABSOLUTELY NO WARRANTY.
+  
   This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
+  modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later verjsion.
-
+  version 2.1 of the License, or (at your option) any later version.
+  
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public
-  License along with this library; if not, write to the
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
-*/
+  Lesser General Public License for more details.
+  
+  You should have received a copy of the GNU Lesser General Public
+  License along with this library; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*/  
 #ifndef _MECAB_MECAB_H
 #define _MECAB_MECAB_H
 
@@ -54,6 +53,7 @@ struct _mecab_node_t
   struct _mecab_path_t  *path;
   char  *surface;
   char  *feature;
+  unsigned char stat; // status 
   unsigned int  length;
   unsigned int  end;
   unsigned int  cost;
@@ -72,15 +72,14 @@ extern "C" {
 #endif
 
 #ifdef _WIN32
+#include <windows.h>
 #  ifdef DLL_EXPORT
-#    define MECAB_DLL_EXTERN    __declspec(dllexport)
+#    define MECAB_DLL_EXTERN  __declspec(dllexport)
 #  else
-#    ifdef  MECAB_DLL_IMPORT
-#      define MECAB_DLL_EXTERN  __declspec(dllimport)
-#    endif
+#    define MECAB_DLL_EXTERN  __declspec(dllimport)
 #  endif
 #endif
-
+   
 #ifndef MECAB_DLL_EXTERN
 #  define MECAB_DLL_EXTERN extern
 #endif 
@@ -89,7 +88,7 @@ extern "C" {
   typedef struct _mecab_node_t  mecab_node_t;
   typedef struct _mecab_path_t  mecab_path_t;
   typedef struct _mecab_token_t mecab_token_t;
-
+   
   /* C interface */
   MECAB_DLL_EXTERN int           mecab_do                  (int, char**);
   MECAB_DLL_EXTERN int           mecab_make_dictionary     (char*, char*);
@@ -108,7 +107,7 @@ extern "C" {
   MECAB_DLL_EXTERN char*         mecab_nbest_sparse_tostr2 (mecab_t*, unsigned int, char*, unsigned int);
   MECAB_DLL_EXTERN char*         mecab_nbest_sparse_tostr3 (mecab_t*, unsigned int, char*, unsigned int, char*, unsigned int);
   MECAB_DLL_EXTERN int           mecab_nbest_init          (mecab_t*, char*);
-  MECAB_DLL_EXTERN int           mecab_nbest_init2         (mecab_t*, char*, unsigned int);   
+  MECAB_DLL_EXTERN int           mecab_nbest_init2         (mecab_t*, char*, unsigned int);
   MECAB_DLL_EXTERN char*         mecab_nbest_next_tostr    (mecab_t*);
   MECAB_DLL_EXTERN char*         mecab_nbest_next_tostr2   (mecab_t*, char*, unsigned int);
   MECAB_DLL_EXTERN mecab_node_t* mecab_nbest_next_tonode   (mecab_t*);
@@ -119,18 +118,9 @@ extern "C" {
 
 /* C++ interface */
 #ifdef __cplusplus
-#include <string>
 
 namespace MeCab
 {
-  class Tokenizer;
-  class Viterbi;
-  class Param;
-  class Mutex;
-  class StringBuffer;
-  class Writer;
-  class NBestGenerator; 
-
   typedef struct _mecab_token_t Token;
   typedef struct _mecab_path_t  Path;
   typedef struct _mecab_node_t  Node;
@@ -138,23 +128,14 @@ namespace MeCab
   class Tagger 
   {
   private:
-    Tokenizer*      tokenizer;
-    Viterbi*        viterbi;
-    Mutex*          mutex;
-    StringBuffer*   ostrs;
-    Writer*         writer;
-    NBestGenerator* nbest; 
-    const char*     begin;
-    bool            build_all_lattice;
-    std::string     _what;
-
-    bool       open         (Param &);
+    class Impl;
+    Impl *_impl;
 
   public:
     bool        open           (int, char**);
     bool        open           (const char*);
     bool        close          ();
-    int         parse          (int, char**);
+    int         parse          (int, char**); // mecab_do
     const char* parse          (const char*, unsigned int = 0);
     const char* parse          (const char*, unsigned int, char*, unsigned int);
     Node*       parseToNode    (const char*, unsigned int = 0);
