@@ -1,7 +1,7 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
  
-  $Id: tagger.cpp,v 1.33 2004/06/21 09:34:35 taku-ku Exp $;
+  $Id: tagger.cpp,v 1.34 2004/08/06 18:05:14 taku-ku Exp $;
 
   Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
   This is free software with ABSOLUTELY NO WARRANTY.
@@ -28,6 +28,7 @@
 #include "mecab.h"
 #include "stringbuffer.h"
 #include "writer.h"
+#include "connector.h"
 #include "nbest_generator.h"
 #include <stdexcept>
 #include <cstdio>
@@ -83,7 +84,12 @@ namespace MeCab
     DWORD vt;
     DWORD size = sizeof (v);
    
-    RegOpenKeyEx    (HKEY_CURRENT_USER,"software\\mecab",0,KEY_ALL_ACCESS,&hKey);
+    RegOpenKeyEx    (HKEY_LOCAL_MACHINE,"software\\mecab",0,KEY_READ,&hKey);
+    RegQueryValueEx (hKey,"mecabrc",0,&vt,(BYTE *)v,&size);
+    RegCloseKey (hKey);
+    if (vt == REG_SZ) return std::string (v);
+     
+    RegOpenKeyEx    (HKEY_CURRENT_USER,"software\\mecab",0,KEY_READ,&hKey);
     RegQueryValueEx (hKey,"mecabrc",0,&vt,(BYTE *)v,&size);
     RegCloseKey (hKey);
     if (vt == REG_SZ) return std::string (v);
@@ -103,12 +109,13 @@ namespace MeCab
     return dicdir;
   }
 
-#define TAGGER_INITILIZE  tokenizer(0), build_all_lattice(0)
+#define TAGGER_INITILIZE  tokenizer(0), connector (0), build_all_lattice(0)
 
   class Tagger::Impl 
   {
   private:
     Tokenizer      *tokenizer;
+    Connector      *connector;
     Viterbi        viterbi;
     Mutex          mutex;
     StringBuffer   ostrs;
@@ -210,9 +217,10 @@ namespace MeCab
       build_all_lattice = (bool)param.getProfileInt ("build-all-lattice");
 
       tokenizer = new JapaneseTokenizer (param);
+      connector = new Connector (param);
 
-      if (! viterbi.open (param, tokenizer)) throw std::runtime_error (viterbi.what());
-      if (! writer.open (param))             throw std::runtime_error (writer.what());
+      if (! viterbi.open (param, tokenizer, connector)) throw std::runtime_error (viterbi.what());
+      if (! writer.open (param))                        throw std::runtime_error (writer.what());
       
       return true;
     }
@@ -310,6 +318,7 @@ namespace MeCab
   bool Tagger::Impl::close ()
   {
     delete tokenizer; tokenizer = 0;
+    delete connector; connector = 0;
     build_all_lattice = false;
     return true;
   }
