@@ -1,7 +1,7 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
  
-  $Id: tokenizer.cpp,v 1.2 2004/03/08 07:40:54 taku-ku Exp $;
+  $Id: tokenizer.cpp,v 1.3 2004/08/06 18:05:14 taku-ku Exp $;
 
   Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
   This is free software with ABSOLUTELY NO WARRANTY.
@@ -93,18 +93,6 @@ namespace MeCab {
       bosFeature    = mystrdup (param.getProfileString ("bos-feature").c_str());
       eosFeature    = mystrdup (param.getProfileString ("eos-feature").c_str());
 
-      // open connection table
-      std::string connectFile = createFileName (prefix, CONNECTION_FILE);
-	
-      if (! cmmap.open (connectFile.c_str()))
-	throw std::runtime_error (cmmap.what ());
-
-      size1 = cmmap[0]; size2 = cmmap[1]; size3 = cmmap[2];
-      if (size1 * size2 * size3 != (cmmap.size()-3))
-	throw std::runtime_error ("file size is invalid");
-	
-      matrix = cmmap.begin () + 3;
-
       return true;
     }
 
@@ -120,6 +108,6 @@ namespace MeCab {
     delete [] unkFeature; unkFeature = 0;
     delete [] bosFeature; bosFeature = 0;
     delete [] eosFeature; eosFeature = 0;
-    return dic.close () && cmmap.close();
+    return dic.close ();
   }
 }
