@@ -1,7 +1,7 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
  
-  $Id: tokenizer.h,v 1.15 2004/03/08 07:40:55 taku-ku Exp $;
+  $Id: tokenizer.h,v 1.16 2004/08/06 18:05:14 taku-ku Exp $;
 
   Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
   This is free software with ABSOLUTELY NO WARRANTY.
@@ -38,11 +38,6 @@ namespace MeCab {
     unsigned int id;
 
   protected:
-    Mmap <unsigned short> cmmap;
-    unsigned short *matrix;
-    unsigned int size1;
-    unsigned int size2;
-    unsigned int size3;
      
     Token bosToken, bosToken2, eosToken, unkToken;
     Node  *bosNode, *bosNode2, *eosNode;
@@ -88,13 +83,6 @@ namespace MeCab {
     virtual void postprocess (const char *, const char *) = 0;
     virtual Node *lookup     (const char *, const char *) = 0;
 
-    // virtual functions, share implimentation, but can be rewritten
-    virtual unsigned int getCost (const Node *lNode2, const Node *lNode, const Node *rNode)
-    {
-       return matrix [size3 * (size2 * lNode2->token->rcAttr2 
-			       + lNode->token->rcAttr1) + rNode->token->lcAttr] + rNode->token->cost;
-    }
-
     virtual bool open (Param &);
     virtual bool close ();
     virtual void clear ();
