@@ -1,7 +1,7 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
  
-  $Id: viterbi.cpp,v 1.17 2004/06/21 09:34:35 taku-ku Exp $;
+  $Id: viterbi.cpp,v 1.18 2004/08/06 18:05:14 taku-ku Exp $;
 
   Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
   This is free software with ABSOLUTELY NO WARRANTY.
@@ -31,10 +31,10 @@ namespace MeCab {
 
   Viterbi::Viterbi () : alloc_size (MIN_INPUT_BUFFER_SIZE) {};
 
-  Viterbi::Viterbi (Param &param, Tokenizer *t)
+  Viterbi::Viterbi (Param &param, Tokenizer *t, Connector *c)
      : alloc_size (MIN_INPUT_BUFFER_SIZE)
   {
-    if (! open (param, t)) throw std::runtime_error (_what);
+    if (! open (param, t, c)) throw std::runtime_error (_what);
   }
 
   Viterbi::~Viterbi () 
@@ -42,11 +42,12 @@ namespace MeCab {
     close ();
   }
 
-  bool Viterbi::open (Param &param, Tokenizer *t)
+  bool Viterbi::open (Param &param, Tokenizer *t, Connector *c)
   {
     try {
 
       tokenizer = t;
+      connector = c; 
      
       if (param.getProfileInt ("build-all-lattice")) {
 	pathFreeList = new FreeList<Path> (PATH_FREELIST_SIZE);
