@@ -1,7 +1,7 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
  
-  $Id: viterbi.h,v 1.14 2004/06/21 09:34:35 taku-ku Exp $;
+  $Id: viterbi.h,v 1.15 2004/08/06 18:05:14 taku-ku Exp $;
 
   Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
   This is free software with ABSOLUTELY NO WARRANTY.
@@ -25,6 +25,7 @@
 
 #include "mecab.h"
 #include "tokenizer.h"
+#include "connector.h"
 #include "freelist.h"
 #include "param.h"
 #include <vector>
@@ -36,6 +37,7 @@ namespace MeCab {
   {
   protected:
     Tokenizer* tokenizer;
+    Connector* connector;  
     Node*      eosNode;
     Node*      bosNode;
     char*      begin;
@@ -61,9 +63,9 @@ namespace MeCab {
     void setTokenizer (Tokenizer *t) { tokenizer = t; }
     const char *what () { return _what.c_str(); }
     void close ();
-    bool open (Param&, Tokenizer*);
+    bool open (Param&, Tokenizer*, Connector *);
     Viterbi ();
-    Viterbi (Param&, Tokenizer*);
+    Viterbi (Param&, Tokenizer*, Connector *);
     ~Viterbi ();
   }; 
 }
