@@ -1,7 +1,7 @@
 /*
   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
  
-  $Id: viterbisub.h,v 1.13 2004/03/08 07:40:55 taku-ku Exp $;
+  $Id: viterbisub.h,v 1.14 2004/08/06 18:05:14 taku-ku Exp $;
 
   Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
   This is free software with ABSOLUTELY NO WARRANTY.
@@ -39,7 +39,7 @@ namespace MeCab {
 
       for (Node *lNode = endNodeList[pos]; lNode; lNode = lNode->lnext) {
 
-	register unsigned int cost = lNode->cost + tokenizer->getCost (lNode->prev, lNode, rNode);
+	register unsigned int cost = lNode->cost + connector->getCost (lNode->prev, lNode, rNode);
 	 
 	if (cost < bestCost) {
 	  bestNode  = lNode;
@@ -73,7 +73,7 @@ namespace MeCab {
 	if (begin + pos2 == end) continue;
 	Node *rNode2 = lookup (pos2);
 	for (; rNode2; rNode2 = rNode2->rnext) {
-	   rNode2->cost   = rNode->cost + tokenizer->getCost (rNode->prev, rNode, rNode2);
+	   rNode2->cost   = rNode->cost + connector->getCost (rNode->prev, rNode, rNode2);
 
 #ifdef _VITERBI_WITH_ALL_PATH
 	  Path *path = pathFreeList->alloc ();
