@@ -51,7 +51,7 @@ namespace MeCab {
     return '\0'; // never be here
   }
 
-#define WRITER_INITILIZE  node_format (0), bos_format (0), eos_format (0)
+#define WRITER_INITILIZE  node_format (0), bos_format (0), eos_format (0), unk_format(0)
 
   Writer::Writer (Param &param): WRITER_INITILIZE
   {
